@@ -29,7 +29,7 @@ use vars qw{$LastErr $LastErrstr *LastErr *LastErrstr *LastError $PreserveCase}
 *PreserveCase   = \$DBIx::Recordset::PreserveCase;
 
 
-use Carp ;
+use Carp qw(confess);
 
 use File::Spec ;
 use DBIx::Recordset ;
@@ -54,7 +54,7 @@ sub savecroak
 
     #$Carp::extra = 1 ;
     #Carp::croak $msg ;
-    Carp::confess $msg ;
+    confess($msg);
     }
 
 ## ----------------------------------------------------------------------------
@@ -214,6 +214,7 @@ sub QueryMetaData($$)
     my $i ;
 
     foreach $tab (@tabs)
+
         {
         next if ($tab =~ /^\s*$/) ;
     
@@ -348,6 +349,8 @@ sub QueryMetaData($$)
                 my $tabfilter = $self -> {'*TableFilter'} || '.' ;
                 foreach (@tabs)
                     {
+		    s/^[^a-zA-Z0-9_.]// ;
+		    s/[^a-zA-Z0-9_.]$// ;
                     if ($_ =~ /(^|\.)$tabfilter/i)
                         {
                         @stab = split (/\./);
@@ -564,6 +567,8 @@ sub new
     my $metakey  ;
     my $self ;
 
+
+
     if (!($data_source =~ /^dbi:/i)) 
         {
         $metakey    = "-DATABASE//$1"  ;
@@ -599,6 +604,17 @@ sub new
     my $hdl ;
     $self->{'*DBHdl'} = undef if ($reconnect) ;
 
+
+    if (ref ($data_source) and eval { $data_source->isa('DBI::db') } )
+      {
+
+	  $self->{'*DBHdl'}      = $data_source;
+      }
+    else
+      {
+
+      }
+
     if (!defined ($self->{'*DBHdl'}))
         {
         $hdl = $self->connect ($password) ;
@@ -635,6 +651,8 @@ sub new
             $tabfilter ||= '.' ;
             foreach (@tabs)
                 {
+	        s/^[^a-zA-Z0-9_.]// ;
+		s/[^a-zA-Z0-9_.]$// ;
                 if ($_ =~ /(^|\.)$tabfilter/i)
                     {
                     @stab = split (/\./);
